@@ -39,12 +39,19 @@ class ContextFilter(logging_module.Filter):
             record.id = ''
             return True
 
+    
 
 from whatap.conf.configure import Configure as conf
-
 CONFIG_FILE_NAME = 'whatap.conf'
 LOG_FILE_NAME = 'whatap-hook.log'
 
+isFrappeCommands = "get-frappe-commands" in sys.argv
+
+def whatap_print(*args):
+    if isFrappeCommands:
+        logging.info(*args)
+    else:
+        print(*args)
 
 class Logger(object):
     def __init__(self):
@@ -62,8 +69,8 @@ class Logger(object):
                 os.mkdir(os.environ['WHATAP_LOGS'])
             
             except Exception as e:
-                print('WHATAP: LOG FILE WRITE ERROR.')
-                print(
+                whatap_print('WHATAP: LOG FILE WRITE ERROR.')
+                whatap_print(
                     'WHATAP: Try to execute command. \n  {}'.format(
                         'sudo mkdir -m 777 -p $WHATAP_HOME/logs`'))
         
@@ -86,7 +93,7 @@ class Logger(object):
             
             self.logger.setLevel(logging_module.DEBUG)
         except Exception as e:
-            print('WHATAP: LOGGING ERROR: {}'.format(e))
+            whatap_print('WHATAP: LOGGING ERROR: {}'.format(e))
         else:
             self.print_whatap()
     
@@ -105,7 +112,7 @@ class Logger(object):
                                                 os.environ['WHATAP_CONFIG']))
         str += '{0}: {1}\n\n'.format('Logs', os.environ['WHATAP_LOGS'])
         
-        print(str)
+        whatap_print(str)
         logging.debug(str)
 
 
@@ -125,8 +132,8 @@ def write_file(home, file_name, value):
         f.write(value)
         f.close()
     except Exception as e:
-        print('WHATAP: WHATAP HOME ERROR. (path: {})'.format(os.path.join(os.environ.get(home))))
-        print(
+        whatap_print('WHATAP: WHATAP HOME ERROR. (path: {})'.format(os.path.join(os.environ.get(home))))
+        whatap_print(
             'WHATAP: Try to execute command. \n  {}'.format(
                 '`sudo chmod -R 777 $WHATAP_HOME`'))
         return False
@@ -137,7 +144,7 @@ def write_file(home, file_name, value):
 def check_whatap_home(target='WHATAP_HOME'):
     whatap_home = os.environ.get(target)
     if not whatap_home:
-        print('WHATAP: ${} is empty'.format(target))
+        whatap_print('WHATAP: ${} is empty'.format(target))
     
     return whatap_home
 
@@ -150,10 +157,10 @@ def init_config(home):
             whatap_home = os.getcwd()
             os.environ[home] = whatap_home
             
-            print('WHATAP: WHATAP_HOME is empty')
-            print(
+            whatap_print('WHATAP: WHATAP_HOME is empty')
+            whatap_print(
                 'WHATAP: WHATAP_HOME set default CURRENT_WORKING_DIRECTORY value')
-            print('CURRENT_WORKING_DIRECTORY is {}\n'.format(whatap_home))
+            whatap_print('CURRENT_WORKING_DIRECTORY is {}\n'.format(whatap_home))
     
     if not write_file(home, home.lower(), whatap_home):
         return False
@@ -172,8 +179,8 @@ def init_config(home):
                 with open(config_file, 'w+') as new_f:
                     new_f.write(content)
             except Exception as e:
-                print('WHATAP: PERMISSION ERROR: {}'.format(e))
-                print(
+                whatap_print('WHATAP: PERMISSION ERROR: {}'.format(e))
+                whatap_print(
                     'WHATAP: Try to execute command. \n  {}'.format(
                         '`sudo chmod -R 777 $WHATAP_HOME`'))
                 return False
@@ -202,7 +209,7 @@ def update_config(home, opt_key, opt_value):
             open(config_file, 'w+').write(content)
     
     except Exception as e:
-        print('WHATAP: OPTION ERROR: {}'.format(e))
+        whatap_print('WHATAP: OPTION ERROR: {}'.format(e))
 
 
 def config(home):
@@ -285,10 +292,10 @@ def agent():
             whatap_home = os.getcwd()
             os.environ[home] = whatap_home
             
-            print('WHATAP: WHATAP_HOME is empty')
-            print(
+            whatap_print('WHATAP: WHATAP_HOME is empty')
+            whatap_print(
                 'WHATAP: WHATAP_HOME set default CURRENT_WORKING_DIRECTORY value')
-            print('CURRENT_WORKING_DIRECTORY is {}\n'.format(whatap_home))
+            whatap_print('CURRENT_WORKING_DIRECTORY is {}\n'.format(whatap_home))
     
     if write_file(home, home.lower(), whatap_home):
         os.environ['WHATAP_HOME'] = whatap_home
@@ -363,13 +370,13 @@ def go(batch=False, opts={}):
         process = subprocess.Popen(['./{0}'.format(AGENT_NAME), '-t', '3', '-d', '1'],
                                    cwd=home_path,env=newenv, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         stdouts, errs = process.communicate()
-        print("executed golang module ", stdouts, errs)
+        whatap_print("executed golang module ", stdouts, errs)
     except Exception as e:
         import traceback
         traceback.print_exc()
-        print('WHATAP: AGENT ERROR: {}'.format(e))
+        whatap_print('WHATAP: AGENT ERROR: {}'.format(e))
     else:
-        print('WHATAP: AGENT UP! (process name: {})\n'.format(AGENT_NAME))
+        whatap_print('WHATAP: AGENT UP! (process name: {})\n'.format(AGENT_NAME))
 
 import signal
 
@@ -427,7 +434,7 @@ def batch_agent():
     batch_home = os.environ.get(home)
     if not batch_home:
         if not read_file(home, home.lower()):
-            print('WHATAP: WHATAP_HOME_BATCH is empty')
+            whatap_print('WHATAP: WHATAP_HOME_BATCH is empty')
             return
     
     if write_file(home, home.lower(), batch_home):
@@ -446,7 +453,7 @@ def batch_profiling(fn):
             home = 'WHATAP_HOME_BATCH'
             batch_home = read_file(home, home.lower())
             if not batch_home:
-                print(
+                whatap_print(
                     'WHATAP(@batch_profiling): try, whatap-start-batch')
                 return fn(*args, **kwargs)
             else:
@@ -496,7 +503,7 @@ def openPortFile(filepath=os.environ.get('WHATAP_LOCK_FILE', '/tmp/whatap-python
             fcntl.lockf(f, fcntl.LOCK_EX)
             return f
         except Exception as e:
-            print(e)
+            whatap_print(e)
             try:
                 f.close()
             except:
