@@ -3,12 +3,22 @@ from . import udp_session
 from whatap.conf.configure import Configure as conf
 q = queue.Queue(conf.max_send_queue_size)
 
+from enum import Enum
+class SendType(Enum):
+    DATAS = 1
+    RELAY = 2
+
 def send_packet( packet_type, ctx, datas=[]):
     global q
     if q.full():
         return
-    q.put((packet_type, ctx, datas))
+    q.put((SendType.DATAS, (packet_type, ctx, datas)))
 
+def send_relaypack( packbytes):
+    global q
+    if q.full():
+        return
+    q.put((SendType.RELAY, packbytes))
 
 def startWhatapThread():
     def __sendPackets():
@@ -18,9 +28,13 @@ def startWhatapThread():
             if not packet_env:
                 time.sleep(0.1)
                 continue
-            packet_type, ctx, datas = packet_env
-            udp_session.UdpSession.send_packet(packet_type, ctx, datas)
-            
+            sendType,params = packet_env
+            if sendType == SendType.DATAS:
+                packet_type, ctx, datas = params
+                udp_session.UdpSession.send_packet(packet_type, ctx, datas)
+            elif sendType == SendType.RELAY:
+                packbytes = params
+                udp_session.UdpSession.send_relaypack(packbytes)    
     t = threading.Thread(target=__sendPackets)
     t.setDaemon(True)
     t.start()
