@@ -6,13 +6,20 @@ import time
 import logging
 import socket
 import errno
+import socket
+from . import stackhelper
 
+from whatap.conf.configure import Configure as conf
 from whatap.io import DataOutputX
 from whatap.net.packet_enum import PacketEnum
 from whatap.net.packet_type_enum import PacketTypeEnum
 from whatap.net.param_def import ParamDef
 from whatap.trace import TraceContextManager
 
+if sys.version_info >= (3, 8):
+    from importlib import metadata as importlib_metadata
+else:
+    import importlib_metadata
 
 class UdpSession(object):
     s = None
@@ -23,8 +30,7 @@ class UdpSession(object):
 
     @classmethod
     def udp(cls):
-        import socket, struct
-        from whatap.conf.configure import Configure as conf
+        
         home = 'WHATAP_HOME'
         whatap_home = os.environ.get(home,'')
 
@@ -158,7 +164,28 @@ class UdpSession(object):
                 conf.init(display=False)
             else:
                 raise serr
+    
+    @classmethod    
+    def getThreadStackFaultHandler(cls, thread_id):
+        stackhelper.StackParser.parse()
+        for line, line_num, method_name in stackhelper.StackParser.find(thread_id):
+            if line.find('/whatap/trace') > -1 or line.find('/threading.py') > -1:
+                continue
+            yield '{} ({}:{})\n'.format(method_name, line, line_num)
 
+    
+    @classmethod    
+    def getThreadStack(cls, frame):
+        for stack in traceback.extract_stack(frame):
+            line = stack[0]
+            line_num = stack[1]
+            method_name = stack[2]
+
+            if line.find('/whatap/trace') > -1 or line.find('/threading.py') > -1:
+                continue
+            yield '{} ({}:{})\n'.format(method_name, line, line_num)
+
+    
     @classmethod
     def handle(cls, received):
         param_id, request, extra = tuple(received)
@@ -174,21 +201,19 @@ class UdpSession(object):
             # active stack pack
             datas = []
             data = extra.replace(' ', ', ')
-
+            
             frame = sys._current_frames().get(thread_id)
             if not frame:
                 return
 
-            for stack in traceback.extract_stack(frame):
-                line = stack[0]
-                line_num = stack[1]
-                method_name = stack[2]
-
-                if line.find('/whatap/trace') > -1 or line.find('/threading.py') > -1:
-                    continue
-                data += '{} ({}:{})\n'.format(method_name, line, line_num)
-
-            datas.append(data)
+            if conf.threadstack_faulthandler:
+                for stack in cls.getThreadStackFaultHandler(thread_id):
+                    data += stack
+                datas.append(data)
+            else:
+                for stack in cls.getThreadStack(frame):
+                    data += stack
+                datas.append(data)
 
             cls.send_packet(PacketTypeEnum.ACTIVE_STACK, None, datas)
             stats = TraceContextManager.getActiveStats()
@@ -199,11 +224,10 @@ class UdpSession(object):
             # format: "[packetType], [ctx], [datas: xxxx xxxx xxxx]"
             datas = [str(param_id), request]
             if param_id == ParamDef.MODULE_DEPENDENCY:
-                try:
-                    from pip._internal.utils.misc import get_installed_distributions
-                except ImportError:
-                    from pip import get_installed_distributions
-                data = ', '.join(map(str, list(get_installed_distributions())))
+                
+                data = ', '.join(map(str, [ "{} {}". \
+                                format(dist.metadata["Name"], \
+                                       dist.version) for dist in importlib_metadata.distributions()]))
                 datas.append(data)
             elif param_id == ParamDef.GET_ACTIVE_TRANSACTION_DETAIL:
                 data = extra.replace(' ', ', ')
