@@ -4,7 +4,7 @@ import sys
 
 from whatap.conf.configure import Configure as conf
 from whatap.net.packet_type_enum import PacketTypeEnum
-from whatap.net.udp_session import UdpSession
+import whatap.net.async_sender as async_sender
 from whatap.trace.trace_context import TraceContext
 from whatap.trace.trace_context_manager import TraceContextManager
 from whatap.util.date_util import DateUtil
@@ -36,7 +36,7 @@ def sendDebugProfile(ctx, msg):
     if ctx:
         ctx.elapsed = 0
         datas = [' ', ' ', 'DEBUG: ' + msg]
-        UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
+        async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
 
 
 def trace_handler(fn, start=False, preload=None):
@@ -101,7 +101,7 @@ def start_interceptor(ctx):
              ctx.isStaticContents
              ]
     # print("start_interceptor txid:", ctx.id)
-    UdpSession.send_packet(PacketTypeEnum.TX_START, ctx, datas)
+    async_sender.send_packet(PacketTypeEnum.TX_START, ctx, datas)
 
     return ctx
 
@@ -126,7 +126,7 @@ def end_interceptor(thread_id=None, ctx=None):
              ctx.mcaller_pcode, ctx.mcaller_spec, str(ctx.mcaller_url_hash), ctx.mcaller_poid]
     ctx.elapsed = DateUtil.nowSystem() - start_time
 
-    UdpSession.send_packet(PacketTypeEnum.TX_END, ctx, datas)
+    async_sender.send_packet(PacketTypeEnum.TX_END, ctx, datas)
 
 
 def parseServiceName(environ):
@@ -227,7 +227,7 @@ def interceptor(rn_environ, *args, **kwargs):
 
                 datas = ['HTTP-HEADERS', 'HTTP-HEADERS', text]
                 ctx.start_time = DateUtil.nowSystem()
-                UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
+                async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
             return callback
     finally:
         ctx = TraceContextManager.getLocalContext()
@@ -259,7 +259,7 @@ def interceptor_error(status_code, errors):
         errors.append(error)
 
         # errors.append(''.join(traceback.format_list(traceback.extract_stack(sys._current_frames()[ctx.thread.ident]))))
-        UdpSession.send_packet(PacketTypeEnum.TX_ERROR, ctx, errors)
+        async_sender.send_packet(PacketTypeEnum.TX_ERROR, ctx, errors)
 
 
 def interceptor_step_error(e, ctx=None):
@@ -295,13 +295,13 @@ def interceptor_step_error(e, ctx=None):
 
     errors.append(error)
     # errors.append(''.join(traceback.format_list(traceback.extract_stack(sys._current_frames()[ctx.thread.ident]))))
-    UdpSession.send_packet(PacketTypeEnum.TX_ERROR, ctx, errors)
+    async_sender.send_packet(PacketTypeEnum.TX_ERROR, ctx, errors)
 
     if conf.profile_exception_stack:
         desc = '\n'.join(errors)
         datas = [' ', ' ', desc]
         ctx.start_time = DateUtil.nowSystem()
-        UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
+        async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
 
 
 def interceptor_httpc_request(fn, httpc_url, *args, **kwargs):
@@ -332,7 +332,7 @@ def interceptor_httpc_request(fn, httpc_url, *args, **kwargs):
         # ctx = TraceContextManager.getLocalContext()
         datas = [ctx.httpc_url, ctx.mcallee]
         ctx.elapsed = DateUtil.nowSystem() - start_time
-        UdpSession.send_packet(PacketTypeEnum.TX_HTTPC, ctx, datas)
+        async_sender.send_packet(PacketTypeEnum.TX_HTTPC, ctx, datas)
 
         if conf.profile_http_parameter_enabled:
             if type(args[1]) == dict:
@@ -342,7 +342,7 @@ def interceptor_httpc_request(fn, httpc_url, *args, **kwargs):
             if param:
                 datas = ['HTTP-PARAMETERS', method, param]
                 ctx.start_time = DateUtil.nowSystem()
-                UdpSession.send_packet(PacketTypeEnum.TX_SECURE_MSG, ctx, datas)
+                async_sender.send_packet(PacketTypeEnum.TX_SECURE_MSG, ctx, datas)
 
         ctx.active_httpc_hash = 0
         ctx.httpc_url = None
@@ -395,7 +395,7 @@ def interceptor_db_con(fn, db_type, *args, **kwargs):
 
     datas = [text]
     ctx.elapsed = DateUtil.nowSystem() - start_time
-    UdpSession.send_packet(PacketTypeEnum.TX_DB_CONN, ctx, datas)
+    async_sender.send_packet(PacketTypeEnum.TX_DB_CONN, ctx, datas)
 
     return callback
 
@@ -460,14 +460,14 @@ def interceptor_db_execute(fn, *args, **kwargs):
         ctx = TraceContextManager.getLocalContext()
         datas = [ctx.lctx.get('dbc', ''), query]
         ctx.elapsed = DateUtil.nowSystem() - start_time
-        UdpSession.send_packet(PacketTypeEnum.TX_SQL, ctx,
+        async_sender.send_packet(PacketTypeEnum.TX_SQL, ctx,
                                datas)
         count = self.rowcount
         if count > -1:
             desc = '{0}: {1}'.format('Fetch count', count)
             datas = [' ', ' ', desc]
             ctx.elapsed = 0
-            UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
+            async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
 
         ctx.active_sqlhash = 0
 
@@ -487,7 +487,7 @@ def interceptor_db_close(fn, *args, **kwargs):
     text = 'DB: Close Connection.'
     datas = [' ', ' ', text]
     ctx.elapsed = DateUtil.nowSystem() - start_time
-    UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
+    async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
     return callback
 
 
